@@ -1,9 +1,9 @@
 #define YY_Tparser_h_included
 
-/*  A Bison parser, made from ../d.y  */
+/*  A Bison parser, made from ./d.y  */
 
 
-#line 1 "../pars/bison.cc"
+#line 1 "./pars/bison.cc"
 /* -*-C-*-  Note some compilers choke on comments on `#line' lines.  */
 /* Skeleton output parser for bison,
    Copyright (C) 1984, 1989, 1990 Bob Corbett and Richard Stallman
@@ -73,14 +73,14 @@
 #include <stdio.h>
 #define YYBISON 1  
 
-/* #line 69 "../pars/bison.cc" */
+/* #line 69 "./pars/bison.cc" */
 #define YY_Tparser_LEX_BODY  {return 0;}		/* otherwise flex++ doesn't seem to work */
 #define YY_Tparser_MEMBERS  \
 	Tnode*nodeptr;	 		/* we return the parsed tree via Tparser::nodeptr */ \
 	const Tchar*filename;	/* the input file name for error messages */ \
 	int oldlineno;			/* the old line number */ \
 	int wasSyntaxError;
-#line 10 "../d.y"
+#line 10 "./d.y"
 
 
 #include <stdio.h>
@@ -106,7 +106,7 @@ static TObjectPtr tmp(TObjectPtr);	// pass through TObjectPtr, flagging it tempo
 static Tnode* DotProduct(Tnode*U, Tnode*V);
 
 
-#line 38 "../d.y"
+#line 38 "./d.y"
 typedef union {
 	Tnode	*node_val;
 	Treal	real_val;
@@ -117,7 +117,7 @@ typedef union {
 } yy_Tparser_stype;
 #define YY_Tparser_STYPE yy_Tparser_stype
 
-#line 69 "../pars/bison.cc"
+#line 69 "./pars/bison.cc"
 /* %{ and %header{ and %union, during decl */
 #define YY_Tparser_BISON 1
 #ifndef YY_Tparser_COMPATIBILITY
@@ -154,32 +154,32 @@ typedef union {
 
 #ifndef YY_Tparser_PURE
 
-/* #line 104 "../pars/bison.cc" */
+/* #line 104 "./pars/bison.cc" */
 
-#line 104 "../pars/bison.cc"
+#line 104 "./pars/bison.cc"
 /*  YY_Tparser_PURE */
 #endif
 
 /* section apres lecture def, avant lecture grammaire S2 */
 
-/* #line 108 "../pars/bison.cc" */
+/* #line 108 "./pars/bison.cc" */
 
-#line 108 "../pars/bison.cc"
+#line 108 "./pars/bison.cc"
 /* prefix */
 #ifndef YY_Tparser_DEBUG
 
-/* #line 110 "../pars/bison.cc" */
+/* #line 110 "./pars/bison.cc" */
 
-#line 110 "../pars/bison.cc"
+#line 110 "./pars/bison.cc"
 /* YY_Tparser_DEBUG */
 #endif
 
 
 #ifndef YY_Tparser_LSP_NEEDED
 
-/* #line 115 "../pars/bison.cc" */
+/* #line 115 "./pars/bison.cc" */
 
-#line 115 "../pars/bison.cc"
+#line 115 "./pars/bison.cc"
  /* YY_Tparser_LSP_NEEDED*/
 #endif
 
@@ -288,7 +288,7 @@ typedef
 #endif
 
 
-/* #line 222 "../pars/bison.cc" */
+/* #line 222 "./pars/bison.cc" */
 #define	INTEGER	258
 #define	REAL	259
 #define	iREAL	260
@@ -341,7 +341,7 @@ typedef
 #define	NOT	307
 
 
-#line 222 "../pars/bison.cc"
+#line 222 "./pars/bison.cc"
  /* #defines tokens */
 #else
 /* CLASS */
@@ -374,7 +374,7 @@ class YY_Tparser_CLASS YY_Tparser_INHERIT
 {
 public: /* static const int token ... */
 
-/* #line 253 "../pars/bison.cc" */
+/* #line 253 "./pars/bison.cc" */
 static const int INTEGER;
 static const int REAL;
 static const int iREAL;
@@ -427,7 +427,7 @@ static const int UNARY_PLUS;
 static const int NOT;
 
 
-#line 253 "../pars/bison.cc"
+#line 253 "./pars/bison.cc"
  /* decl const */
 public:
  int YY_Tparser_PARSE (YY_Tparser_PARSE_PARAM);
@@ -457,7 +457,7 @@ public:
 };
 /* other declare folow */
 
-/* #line 281 "../pars/bison.cc" */
+/* #line 281 "./pars/bison.cc" */
 const int YY_Tparser_CLASS::INTEGER=258;
 const int YY_Tparser_CLASS::REAL=259;
 const int YY_Tparser_CLASS::iREAL=260;
@@ -510,7 +510,7 @@ const int YY_Tparser_CLASS::UNARY_PLUS=306;
 const int YY_Tparser_CLASS::NOT=307;
 
 
-#line 281 "../pars/bison.cc"
+#line 281 "./pars/bison.cc"
  /* const YY_Tparser_CLASS::token */
 /*apres const  */
 YY_Tparser_CLASS::YY_Tparser_CLASS(YY_Tparser_CONSTRUCTOR_PARAM) YY_Tparser_CONSTRUCTOR_INIT
@@ -522,7 +522,7 @@ YY_Tparser_CONSTRUCTOR_CODE;
 };
 #endif
 
-/* #line 291 "../pars/bison.cc" */
+/* #line 291 "./pars/bison.cc" */
 
 
 #define	YYFINAL		239
@@ -956,7 +956,7 @@ static const short yycheck[] = {     0,
     53,    54,    -1,    -1,    57
 };
 
-#line 291 "../pars/bison.cc"
+#line 291 "./pars/bison.cc"
  /* fattrs + tables */
 
 /* parser code folow  */
@@ -1363,166 +1363,166 @@ yyreduce:
 #endif
 
 
-/* #line 696 "../pars/bison.cc" */
+/* #line 696 "./pars/bison.cc" */
 
   switch (yyn) {
 
 case 1:
-#line 83 "../d.y"
+#line 83 "./d.y"
 { nodeptr = yyval.node_val = yyvsp[-1].node_val; YYACCEPT; ;
     break;}
 case 2:
-#line 84 "../d.y"
+#line 84 "./d.y"
 { YYERROR; ;
     break;}
 case 3:
-#line 87 "../d.y"
+#line 87 "./d.y"
 { yyval.node_val = new Tnode(yyvsp[0].node_val,FBLOCK,0); ;
     break;}
 case 4:
-#line 88 "../d.y"
+#line 88 "./d.y"
 { yyval.node_val = FlatOperator(yyvsp[-2].node_val,yyvsp[0].node_val,FBLOCK); ;
     break;}
 case 5:
-#line 91 "../d.y"
+#line 91 "./d.y"
 { yyval.node_val = new Tnode(0,FNOP,0); ;
     break;}
 case 6:
-#line 92 "../d.y"
+#line 92 "./d.y"
 { yyval.node_val = yyvsp[0].node_val; ;
     break;}
 case 8:
-#line 96 "../d.y"
+#line 96 "./d.y"
 { yyval.node_val = NList(FSET,yyvsp[-3].node_val,yyvsp[0].node_val); ;
     break;}
 case 24:
-#line 112 "../d.y"
+#line 112 "./d.y"
 { yyval.node_val = yyvsp[-1].node_val; ;
     break;}
 case 25:
-#line 113 "../d.y"
+#line 113 "./d.y"
 { yyval.node_val = 0; ;
     break;}
 case 26:
-#line 116 "../d.y"
+#line 116 "./d.y"
 { yyval.node_val = new Tnode(yyvsp[0].node_val,FSET,0); ;
     break;}
 case 27:
-#line 117 "../d.y"
+#line 117 "./d.y"
 { yyvsp[-2].node_val->next = yyvsp[0].node_val; yyval.node_val = new Tnode(yyvsp[-2].node_val,FSET,0); ;
     break;}
 case 28:
-#line 118 "../d.y"
+#line 118 "./d.y"
 { Tnode*n1 = new Tnode(*yyvsp[-2].node_val); yyval.node_val = NList(FSET,n1,NList(FPLUS,yyvsp[-2].node_val,yyvsp[0].node_val)); ;
     break;}
 case 29:
-#line 119 "../d.y"
+#line 119 "./d.y"
 { Tnode*n1 = new Tnode(*yyvsp[-2].node_val); yyval.node_val = NList(FSET,n1,NList(FDIFFERENCE,yyvsp[-2].node_val,yyvsp[0].node_val)); ;
     break;}
 case 30:
-#line 120 "../d.y"
+#line 120 "./d.y"
 { Tnode*n1 = new Tnode(*yyvsp[-2].node_val); yyval.node_val = NList(FSET,n1,NList(FTIMES,yyvsp[-2].node_val,yyvsp[0].node_val)); ;
     break;}
 case 31:
-#line 121 "../d.y"
+#line 121 "./d.y"
 { Tnode*n1 = new Tnode(*yyvsp[-2].node_val); yyval.node_val = NList(FSET,n1,NList(FQUOTIENT,yyvsp[-2].node_val,yyvsp[0].node_val)); ;
     break;}
 case 32:
-#line 124 "../d.y"
+#line 124 "./d.y"
 {
 			nodeptr = yyval.node_val = NList(FDEFUN,new Tnode(0,yyvsp[-7].sym_val,0),new Tnode(),yyvsp[-5].node_val,yyvsp[-3].node_val,yyvsp[-1].node_val);
 		;
     break;}
 case 33:
-#line 127 "../d.y"
+#line 127 "./d.y"
 {
 			nodeptr = yyval.node_val = NList(FDEFUN,new Tnode(0,yyvsp[-7].sym_val,0),new Tnode(0,yyvsp[-9].sym_val,0),yyvsp[-5].node_val,yyvsp[-3].node_val,yyvsp[-1].node_val);
 		;
     break;}
 case 34:
-#line 130 "../d.y"
+#line 130 "./d.y"
 {
 			nodeptr = yyval.node_val = NList(FDEFUN,new Tnode(0,yyvsp[-7].sym_val,0),yyvsp[-10].node_val,yyvsp[-5].node_val,yyvsp[-3].node_val,yyvsp[-1].node_val);
 		;
     break;}
 case 35:
-#line 135 "../d.y"
+#line 135 "./d.y"
 {
 			yyval.node_val = NList(FPACKAGE,new Tnode(0,tmp(new Tobject(yyvsp[-4].str_val)),0),yyvsp[-3].node_val,yyvsp[-1].node_val);
 		;
     break;}
 case 36:
-#line 138 "../d.y"
+#line 138 "./d.y"
 {
 			yyval.node_val = NList(FPACKAGE,new Tnode(0,tmp(new Tobject(filename)),0),yyvsp[-3].node_val,yyvsp[-1].node_val);
 		;
     break;}
 case 37:
-#line 143 "../d.y"
+#line 143 "./d.y"
 { yyval.node_val = new Tnode(0,FLIST,0); ;
     break;}
 case 38:
-#line 144 "../d.y"
+#line 144 "./d.y"
 { yyval.node_val = NList(FLIST,new Tnode(0,yyvsp[0].sym_val,0)); ;
     break;}
 case 39:
-#line 145 "../d.y"
+#line 145 "./d.y"
 { yyval.node_val = FlatOperator(yyvsp[-2].node_val,new Tnode(0,yyvsp[0].sym_val,0),FLIST); ;
     break;}
 case 41:
-#line 149 "../d.y"
+#line 149 "./d.y"
 { yyval.node_val = NList(FFORMAL,yyvsp[-2].node_val,yyvsp[0].node_val); ;
     break;}
 case 42:
-#line 150 "../d.y"
+#line 150 "./d.y"
 { yyval.node_val = NList(FFORMAL_ELLIPSIS,yyvsp[-1].node_val); ;
     break;}
 case 43:
-#line 151 "../d.y"
+#line 151 "./d.y"
 { yyval.node_val = NList(FFORMAL_ELLIPSIS,yyvsp[-3].node_val,yyvsp[-1].node_val); ;
     break;}
 case 44:
-#line 154 "../d.y"
+#line 154 "./d.y"
 { yyval.node_val = new Tnode(); *yyval.node_val = FLOCAL; ;
     break;}
 case 45:
-#line 155 "../d.y"
+#line 155 "./d.y"
 { yyval.node_val = new Tnode(0,FLOCAL,0); ;
     break;}
 case 46:
-#line 156 "../d.y"
+#line 156 "./d.y"
 { yyval.node_val = yyvsp[-1].node_val; *yyval.node_val = FLOCAL; ;
     break;}
 case 47:
-#line 157 "../d.y"
+#line 157 "./d.y"
 { yyval.node_val = new Tnode(0,FGLOBAL,0); ;
     break;}
 case 48:
-#line 158 "../d.y"
+#line 158 "./d.y"
 { yyval.node_val = yyvsp[-1].node_val; *yyval.node_val = FGLOBAL; ;
     break;}
 case 49:
-#line 161 "../d.y"
+#line 161 "./d.y"
 { yyval.node_val = NList(FIF,yyvsp[-2].node_val,yyvsp[0].node_val); ;
     break;}
 case 50:
-#line 162 "../d.y"
+#line 162 "./d.y"
 { yyval.node_val = NList(FIF,yyvsp[-4].node_val,yyvsp[-2].node_val,yyvsp[0].node_val); ;
     break;}
 case 51:
-#line 164 "../d.y"
+#line 164 "./d.y"
 { yyval.node_val = NList(FWHILE,yyvsp[-2].node_val,yyvsp[0].node_val); ;
     break;}
 case 52:
-#line 167 "../d.y"
+#line 167 "./d.y"
 { yyval.node_val = NList(FREPEAT,yyvsp[-2].node_val,yyvsp[0].node_val); ;
     break;}
 case 53:
-#line 170 "../d.y"
+#line 170 "./d.y"
 { yyval.node_val = NList(FFOR,yyvsp[-6].node_val,yyvsp[-4].node_val,yyvsp[-2].node_val,yyvsp[0].node_val); ;
     break;}
 case 54:
-#line 173 "../d.y"
+#line 173 "./d.y"
 {
 	/* Notice that NList destroys the bindings of its arguments
        (that's why it's NList and not List). Thus we have to recompute
@@ -1558,165 +1558,165 @@ case 54:
 			;
     break;}
 case 55:
-#line 208 "../d.y"
+#line 208 "./d.y"
 { yyval.node_val = new Tnode(0,FBREAK,0); ;
     break;}
 case 56:
-#line 211 "../d.y"
+#line 211 "./d.y"
 { yyval.node_val = new Tnode(0,FCONTINUE,0); ;
     break;}
 case 57:
-#line 214 "../d.y"
+#line 214 "./d.y"
 { yyval.node_val = new Tnode(0,FRETURN,0); ;
     break;}
 case 58:
-#line 217 "../d.y"
+#line 217 "./d.y"
 { yyval.node_val = NList(FGOTO,new Tnode(0,yyvsp[0].sym_val,0)); ;
     break;}
 case 59:
-#line 220 "../d.y"
+#line 220 "./d.y"
 { yyval.node_val = NList(FLABEL,new Tnode(0,yyvsp[0].sym_val,0)); ;
     break;}
 case 60:
-#line 223 "../d.y"
+#line 223 "./d.y"
 {
 				Tnode*n1 = new Tnode(*yyvsp[-1].node_val);
 				yyval.node_val = NList(FSET,n1,NList(FPLUS,yyvsp[-1].node_val,new Tnode(0,tmp(new Tobject(1)),0)));
 			  ;
     break;}
 case 61:
-#line 229 "../d.y"
+#line 229 "./d.y"
 {
 				Tnode*n1 = new Tnode(*yyvsp[-1].node_val);
 				yyval.node_val = NList(FSET,n1,NList(FDIFFERENCE,yyvsp[-1].node_val,new Tnode(0,tmp(new Tobject(1)),0)));
 			  ;
     break;}
 case 62:
-#line 235 "../d.y"
+#line 235 "./d.y"
 { yyval.node_val = new Tnode(yyvsp[0].node_val,FDISP,0); ;
     break;}
 case 64:
-#line 239 "../d.y"
+#line 239 "./d.y"
 { yyval.node_val = new Tnode(0,Tallrange(),0); ;
     break;}
 case 65:
-#line 240 "../d.y"
+#line 240 "./d.y"
 { yyvsp[-2].node_val->next = yyvsp[0].node_val; yyval.node_val = new Tnode(yyvsp[-2].node_val,FRANGE,0); ;
     break;}
 case 66:
-#line 241 "../d.y"
+#line 241 "./d.y"
 { yyvsp[-4].node_val->next = yyvsp[-2].node_val; yyvsp[-2].node_val->next = yyvsp[0].node_val; yyval.node_val = new Tnode(yyvsp[-4].node_val,FRANGE,0); ;
     break;}
 case 67:
-#line 244 "../d.y"
+#line 244 "./d.y"
 { yyval.node_val = yyvsp[-1].node_val; ;
     break;}
 case 68:
-#line 245 "../d.y"
+#line 245 "./d.y"
 { YYERROR; ;
     break;}
 case 69:
-#line 246 "../d.y"
+#line 246 "./d.y"
 { yyval.node_val = yyvsp[-1].node_val; ;
     break;}
 case 70:
-#line 247 "../d.y"
+#line 247 "./d.y"
 { yyval.node_val = NList(FCALL,new Tnode(0,theHT.add((const Tchar*)"herm"),0),yyvsp[-1].node_val); ;
     break;}
 case 71:
-#line 248 "../d.y"
+#line 248 "./d.y"
 { yyval.node_val = NList(FCALL,new Tnode(0,theHT.add((const Tchar*)"transpose"),0),yyvsp[-1].node_val); ;
     break;}
 case 72:
-#line 249 "../d.y"
+#line 249 "./d.y"
 { yyvsp[-2].node_val->next = yyvsp[0].node_val; yyval.node_val = new Tnode(yyvsp[-2].node_val,FEQ,0); ;
     break;}
 case 73:
-#line 250 "../d.y"
+#line 250 "./d.y"
 { yyvsp[-2].node_val->next = yyvsp[0].node_val; yyval.node_val = new Tnode(yyvsp[-2].node_val,FNE,0); ;
     break;}
 case 74:
-#line 251 "../d.y"
+#line 251 "./d.y"
 { yyvsp[-2].node_val->next = yyvsp[0].node_val; yyval.node_val = new Tnode(yyvsp[-2].node_val,FGT,0); ;
     break;}
 case 75:
-#line 252 "../d.y"
+#line 252 "./d.y"
 { yyvsp[-2].node_val->next = yyvsp[0].node_val; yyval.node_val = new Tnode(yyvsp[-2].node_val,FLT,0); ;
     break;}
 case 76:
-#line 253 "../d.y"
+#line 253 "./d.y"
 { yyvsp[-2].node_val->next = yyvsp[0].node_val; yyval.node_val = new Tnode(yyvsp[-2].node_val,FGE,0); ;
     break;}
 case 77:
-#line 254 "../d.y"
+#line 254 "./d.y"
 { yyvsp[-2].node_val->next = yyvsp[0].node_val; yyval.node_val = new Tnode(yyvsp[-2].node_val,FLE,0); ;
     break;}
 case 78:
-#line 255 "../d.y"
+#line 255 "./d.y"
 { yyvsp[-2].node_val->next = yyvsp[0].node_val; yyval.node_val = new Tnode(yyvsp[-2].node_val,FAND,0); ;
     break;}
 case 79:
-#line 256 "../d.y"
+#line 256 "./d.y"
 { yyvsp[-2].node_val->next = yyvsp[0].node_val; yyval.node_val = new Tnode(yyvsp[-2].node_val,F_OR,0); ;
     break;}
 case 80:
-#line 257 "../d.y"
+#line 257 "./d.y"
 { yyvsp[-2].node_val->next = yyvsp[0].node_val; yyval.node_val = new Tnode(yyvsp[-2].node_val,FPLUS,0); ;
     break;}
 case 81:
-#line 258 "../d.y"
+#line 258 "./d.y"
 { yyvsp[-2].node_val->next = yyvsp[0].node_val; yyval.node_val = new Tnode(yyvsp[-2].node_val,FDIFFERENCE,0); ;
     break;}
 case 82:
-#line 259 "../d.y"
+#line 259 "./d.y"
 { yyvsp[-2].node_val->next = yyvsp[0].node_val; yyval.node_val = new Tnode(yyvsp[-2].node_val,FTIMES,0); ;
     break;}
 case 83:
-#line 260 "../d.y"
+#line 260 "./d.y"
 { yyval.node_val = DotProduct(yyvsp[-2].node_val,yyvsp[0].node_val); ;
     break;}
 case 84:
-#line 261 "../d.y"
+#line 261 "./d.y"
 { yyvsp[-2].node_val->next = yyvsp[0].node_val; yyval.node_val = new Tnode(yyvsp[-2].node_val,FQUOTIENT,0); ;
     break;}
 case 85:
-#line 262 "../d.y"
+#line 262 "./d.y"
 { yyvsp[-2].node_val->next = yyvsp[0].node_val; yyval.node_val = new Tnode(yyvsp[-2].node_val,FMOD,0); ;
     break;}
 case 86:
-#line 263 "../d.y"
+#line 263 "./d.y"
 { yyvsp[-2].node_val->next = yyvsp[0].node_val; yyval.node_val = new Tnode(yyvsp[-2].node_val,FPOWER,0); ;
     break;}
 case 87:
-#line 264 "../d.y"
+#line 264 "./d.y"
 { yyval.node_val = new Tnode(yyvsp[0].node_val,FMINUS,0); ;
     break;}
 case 88:
-#line 265 "../d.y"
+#line 265 "./d.y"
 { yyval.node_val = yyvsp[0].node_val; ;
     break;}
 case 89:
-#line 266 "../d.y"
+#line 266 "./d.y"
 { yyval.node_val = new Tnode(yyvsp[0].node_val,FNOT,0); ;
     break;}
 case 91:
-#line 268 "../d.y"
+#line 268 "./d.y"
 { yyval.node_val = new Tnode(0,tmp(new Tobject(yyvsp[0].int_val)),0); ;
     break;}
 case 92:
-#line 269 "../d.y"
+#line 269 "./d.y"
 { yyval.node_val = new Tnode(0,tmp(new Tobject(yyvsp[0].real_val)),0); ;
     break;}
 case 93:
-#line 270 "../d.y"
+#line 270 "./d.y"
 { yyval.node_val = new Tnode(0,tmp(new Tobject(Tcomplex(0,yyvsp[0].real_val))),0); ;
     break;}
 case 94:
-#line 271 "../d.y"
+#line 271 "./d.y"
 { yyval.node_val = new Tnode(0,tmp(new Tobject(yyvsp[0].str_val)),0); ;
     break;}
 case 95:
-#line 272 "../d.y"
+#line 272 "./d.y"
 {
 			TObjectPtr objptr = new Tobject(Tint(yyvsp[0].ch_val));
 			objptr->SetCharFlag();
@@ -1724,11 +1724,11 @@ case 95:
 		;
     break;}
 case 97:
-#line 278 "../d.y"
+#line 278 "./d.y"
 { yyval.node_val = 0; ;
     break;}
 case 98:
-#line 281 "../d.y"
+#line 281 "./d.y"
 {
 					yyval.node_val = NList(FCALL,
                                new Tnode(0,theHT.add((const Tchar*)"izeros"),0),
@@ -1737,27 +1737,27 @@ case 98:
                 ;
     break;}
 case 99:
-#line 287 "../d.y"
+#line 287 "./d.y"
 { yyval.node_val = new Tnode(yyvsp[0].node_val,FARRAY,0); ;
     break;}
 case 101:
-#line 289 "../d.y"
+#line 289 "./d.y"
 { yyval.node_val = FlatOperator(yyvsp[-2].node_val,yyvsp[0].node_val,FARRAY); ;
     break;}
 case 103:
-#line 293 "../d.y"
+#line 293 "./d.y"
 { yyval.node_val = FlatOperator(yyvsp[-2].node_val,yyvsp[0].node_val,FAPP); ;
     break;}
 case 104:
-#line 296 "../d.y"
+#line 296 "./d.y"
 { yyval.node_val = FlatOperator(yyvsp[-2].node_val,yyvsp[0].node_val,FAPP); ;
     break;}
 case 105:
-#line 299 "../d.y"
+#line 299 "./d.y"
 { yyval.node_val = new Tnode(0,yyvsp[0].sym_val,0); ;
     break;}
 case 106:
-#line 300 "../d.y"
+#line 300 "./d.y"
 {
 			yyval.node_val = Append(NList(FREF,yyvsp[-3].node_val/*new Tnode(0,$1,0)*/),yyvsp[-1].node_val);
 			if (Length(yyvsp[-1].node_val) > MAXRANK) {
@@ -1767,7 +1767,7 @@ case 106:
 		;
     break;}
 case 107:
-#line 307 "../d.y"
+#line 307 "./d.y"
 {
 			yyval.node_val = Append(NList(FMREF,yyvsp[-3].node_val/*new Tnode(0,$1,0)*/),yyvsp[-1].node_val);
 			if (Length(yyvsp[-1].node_val) > MAXRANK) {
@@ -1777,40 +1777,40 @@ case 107:
 		;
     break;}
 case 108:
-#line 316 "../d.y"
+#line 316 "./d.y"
 { yyval.node_val = Append(NList(FCALL,new Tnode(0,yyvsp[-3].sym_val,0)),yyvsp[-1].node_val); ;
     break;}
 case 109:
-#line 317 "../d.y"
+#line 317 "./d.y"
 { *yyvsp[-1].node_val = FCALL; yyval.node_val = yyvsp[-1].node_val; ;
     break;}
 case 110:
-#line 320 "../d.y"
+#line 320 "./d.y"
 { yyval.node_val = new Tnode(yyvsp[0].node_val,FLIST,0); ;
     break;}
 case 111:
-#line 321 "../d.y"
+#line 321 "./d.y"
 { yyval.node_val = FlatOperator(yyvsp[-2].node_val,yyvsp[0].node_val,FLIST); ;
     break;}
 case 112:
-#line 324 "../d.y"
+#line 324 "./d.y"
 { yyval.node_val = new Tnode(0,FLIST,0); ;
     break;}
 case 114:
-#line 328 "../d.y"
+#line 328 "./d.y"
 { yyval.node_val = new Tnode(new Tnode(0,yyvsp[0].sym_val,0),FLIST,0); ;
     break;}
 case 115:
-#line 329 "../d.y"
+#line 329 "./d.y"
 { yyval.node_val = FlatOperator(yyvsp[-2].node_val,new Tnode(0,yyvsp[0].sym_val,0),FLIST); ;
     break;}
 case 116:
-#line 332 "../d.y"
+#line 332 "./d.y"
 { yyval.node_val = new Tnode(0,FLIST,0); ;
     break;}
 }
 
-#line 696 "../pars/bison.cc"
+#line 696 "./pars/bison.cc"
    /* the action file gets copied in in place of this dollarsign  */
   yyvsp -= yylen;
   yyssp -= yylen;
@@ -2006,8 +2006,8 @@ yyerrhandle:
 
 /* END */
 
-/* #line 890 "../pars/bison.cc" */
-#line 336 "../d.y"
+/* #line 890 "./pars/bison.cc" */
+#line 336 "./d.y"
 	/* auxiliary functions section */
 
 static Tnode* NList(Tfunc h, Tnode*arg1) {
