@@ -12,7 +12,7 @@
 # Both /* ... */ and sequential // comments are recognized.
 #
 # This script should work in almost any Unix system.
-# It only needs /bin/sh, egrep, more and basic old awk.
+# It only needs /bin/sh, egrep, tail and basic old awk.
 
 fn=$1
 file=$2
@@ -22,7 +22,7 @@ if [ -f "$file" ]; then
 	lines=`egrep -n "^[ \t]*function[^{]*[ \=\\t]${fn}[ \\t]*\\(" "$file" | cut -f1 -d':'`
 	if [ -n "$lines" ]; then
 		for line in $lines; do
-			more +`expr $line + 1` "$file" | awk '
+			tail +`expr $line + 1` "$file" | awk '
 BEGIN {incomment=0; printed=0}
 /\/\*.*/ {
 	printed = 1
